@@ -1,13 +1,21 @@
 # -*- coding: utf-8 -*-
 
-__all__ = ["aesara", "sparse", "tensor", "change_flags", "ifelse", "slinalg"]
+__all__ = ["USE_AESARA", "aesara", "sparse", "change_flags", "ifelse"]
 
 
+USE_AESARA = False
 try:
     import aesara
-
 except ImportError:
+    aesara = None
+else:
+    try:
+        import pymc3.theanof  # noqa
+    except ImportError:
+        USE_AESARA = True
 
+
+if aesara is None or not USE_AESARA:
     try:
         import theano.graph
 
@@ -27,9 +35,9 @@ except ImportError:
     from theano.ifelse import ifelse
 
     try:
-        from theano.configparser import change_flags
-    except ImportError:
         change_flags = theano.config.change_flags
+    except (ImportError, AttributeError):
+        from theano.configparser import change_flags
 
 else:
     # Aesara is installed
